@@ -15,11 +15,11 @@ extern int e_events;
 extern float mix;
 extern float midmix;
 extern float fdim;
-extern float start;
-extern float mean;
-extern float varience;
-extern float shift;
-extern float delta_shadow;
+extern Height start;
+extern Height mean;
+extern Height varience;
+extern Height shift;
+extern Height delta_shadow;
 extern float stretch;
 extern float contour;
 extern float ambient;
@@ -40,7 +40,6 @@ extern Height sealevel;
 extern Height forceheight;
 extern int width;
 extern int seed;
-extern unsigned char red[256] ,green[256], blue[256];
 extern int height;
 extern double vangle;
 extern double tan_vangle;
